@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors: Ross Burton <ross@burtonini.com>
  */
@@ -25,6 +24,6 @@
 
 #include <gtk/gtk.h>
 
-G_MODULE_EXPORT void on_about_activate (void);
+void show_about_dialog (void);
 
 #endif /* SJ_ABOUT_H */
